#
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.
#

# This .spec file uses `rpkg` (https://pagure.io/rpkg-util) to provide
# pleasant user experience to developers.
#
#  Command                  Description
# `rpkg srpm`              Creates a *.src.rpm file in /tmp/rpkg (exact path is printed)
# `rpkg local --nocheck`   Builds a *.rpm for your system in /tmp/rpkg (exact path is printed)
#
# See `man rpkg` for more commands.

# https://bugzilla.redhat.com/show_bug.cgi?id=1668512#c19
%undefine __cmake_in_source_build

%global proton_minimum_version 0.34.0
%global libwebsockets_minimum_version 3.0.1
%global libnghttp2_minimum_version 1.33.0

Name:          skupper-router
Version:       0.0.git.3535.f3305bbf
Release:       2.0.0%{?dist}
Summary:       Router for Skupper.io
License:       ASL 2.0
URL:           https://skupper.io
VCS:           git+https://github.com/jiridanek/skupper-router.git#f3305bbf012ffe5d6781abf027f1ed187bbd52f3:

BuildRequires: gcc
BuildRequires: gcc-c++
BuildRequires: cmake
BuildRequires: python3-devel
BuildRequires: openssl-devel
BuildRequires: qpid-proton-c-devel >= %{proton_minimum_version}
BuildRequires: libwebsockets-devel >= %{libwebsockets_minimum_version}
BuildRequires: libnghttp2-devel >= %{libnghttp2_minimum_version}
# man pages --help
BuildRequires: asciidoc
BuildRequires: python3-qpid-proton >= %{proton_minimum_version}
# check ctest
BuildRequires: cyrus-sasl-plain

Source: skupper-router-f3305bbf.tar.gz

%description
A lightweight message router, written in C and built on Qpid Proton, that provides flexible and scalable interconnect backend for Skupper.io Level 7 Virtual Application Network.

%prep
%setup -T -b 0 -q -n skupper-router

%build
%cmake -DUSE_LIBWEBSOCKETS=ON -DUSE_LIBNGHTTP2=ON -DPython_EXECUTABLE=%{python3}
%cmake_build --target all --target man

%install
%cmake_install

%check
%ctest

%package server
Summary:  The skrouterd deamon
Requires: python3
Requires: qpid-proton-c >= %{proton_minimum_version}
Requires: libwebsockets >= %{libwebsockets_minimum_version}
Requires: libnghttp2 >= %{libnghttp2_minimum_version}

%description server
%{summary}.

%files server
/usr/sbin/skrouterd

%config /etc/skupper-router/skrouterd.conf
%config /etc/sasl2/skrouterd.conf

%{python3_sitelib}/skupper_router/
%{python3_sitelib}/skupper_router_site.py
%{python3_sitelib}/__pycache__/skupper_router_site.*.pyc
%{python3_sitelib}/skupper_router-*.egg-info

# skupper-router-tools depend on tools/command.py, etc. in skupper_router_internal/
/usr/lib/skupper-router/python/skupper_router_internal/

/usr/share/man/man5/skrouterd.conf.5.gz
/usr/share/man/man8/skrouterd.8.gz

/usr/share/skupper-router/html/index.html

%package tools
Summary:  The skstat and skmanage tools for skrouterd
BuildArch: noarch
Requires: python3
Requires: python3-qpid-proton >= %{proton_minimum_version}
Requires: skupper-router-server == %{version}

%description tools
%{summary}.

%files tools
/usr/bin/skmanage
/usr/bin/skstat

/usr/share/man/man8/skstat.8.gz
/usr/share/man/man8/skmanage.8.gz

%package tests
Summary:  Tests for the skupper router and the tools
Requires: python3
Requires: python3-qpid-proton >= %{proton_minimum_version}
Requires: skupper-router-server == %{version}
Requires: skupper-router-tools == %{version}
Requires: cyrus-sasl-plain

%description tests
%{summary}.

%files tests
/usr/lib/skupper-router/tests/

%package docs
Summary:  Documentation for the skupper router
BuildArch: noarch

%description docs
%{summary}.

%files docs
/usr/share/doc/skupper-router/README.adoc
/usr/share/doc/skupper-router/skrouter.json
/usr/share/doc/skupper-router/skrouter.json.readme.txt
%license /usr/share/doc/skupper-router/LICENSE

%changelog
